// This file is part of MultiVnc-Qt.  MultiVnc-Qt is copyright 2012-2022
// by Robert W. Babcock and WSS Division of DDC and is distributed under
// the terms of the GNU General Public License.  Contact the author at
// wssddc@wssddc.com or see the project web page at
// <https://www.wssddc.com/multivnc/>.
//
// MultiVnc-Qt uses the open source Qt toolkit from the Qt Project
// (qt-project.org) and The Qt Company (www.qt.io).
//
// MultiVnc-Qt is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// MultiVnc-Qt is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with MultiVnc-Qt.  If not, see <https://www.gnu.org/licenses/>.

#include <Windows.h>

#include <QString>
#include <QtDebug>
#include <QMessageBox>

#define ENTROPY	NULL

// Encrypt plaintext and return as a base 64 string
QString encryptString(QString plaintext)
	{
	DATA_BLOB DataIn;
	DATA_BLOB DataOut;

	if(0 == plaintext.length())
		return QString();
	QByteArray array = plaintext.toLocal8Bit();
	char *buffer = array.data();
	BYTE *pbDataInput = reinterpret_cast<BYTE *>(buffer);
	DWORD cbDataInput = static_cast<DWORD>(plaintext.length());
	DataIn.cbData = cbDataInput;
	DataIn.pbData = pbDataInput;
	if(!CryptProtectData(&DataIn, nullptr, ENTROPY, nullptr, nullptr, 0, &DataOut))
		{
		QMessageBox::critical(nullptr, "Encryption error", "Password encryption failed.");
		return QString();
		}
	QByteArray encrypted = QByteArray::fromRawData(reinterpret_cast<char *>(DataOut.pbData), static_cast<int>(DataOut.cbData));
	QString result = encrypted.toBase64();
	LocalFree(DataOut.pbData);
	return result;
	}

// Decrypt base 64 string
QString decryptString(QString cyphertext)
	{
	DATA_BLOB DataIn;
	DATA_BLOB DataOut;

	if(0 == cyphertext.length())
		return QString();
	QByteArray array = cyphertext.toLocal8Bit();
	QByteArray encrypted = QByteArray::fromBase64(array);
	char *buffer = encrypted.data();
	BYTE *pbDataInput = reinterpret_cast<BYTE *>(buffer);
	DWORD cbDataInput = static_cast<DWORD>(encrypted.length());
	DataIn.cbData = cbDataInput;
	DataIn.pbData = pbDataInput;
	if(!CryptUnprotectData(&DataIn, nullptr, ENTROPY, nullptr, nullptr, 0, &DataOut))
		{
		QMessageBox::critical(nullptr, "decryption error", "Password decryption failed.");
		return QString();
		}
//	qDebug() << "In/out sizes: " << DataIn.cbData << DataOut.cbData;
	QByteArray decrypted = QByteArray::fromRawData(reinterpret_cast<char *>(DataOut.pbData), static_cast<int>(DataOut.cbData));
	QString result = decrypted;
	LocalFree(DataOut.pbData);
	return result;
	}
