// This file is part of MultiVnc-Qt.  MultiVnc-Qt is copyright 2012-2022
// by Robert W. Babcock and WSS Division of DDC and is distributed under
// the terms of the GNU General Public License.  Contact the author at
// wssddc@wssddc.com or see the project web page at
// <https://www.wssddc.com/multivnc/>.
//
// MultiVnc-Qt uses the open source Qt toolkit from the Qt Project
// (qt-project.org) and The Qt Company (www.qt.io).
//
// MultiVnc-Qt is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// MultiVnc-Qt is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with MultiVnc-Qt.  If not, see <https://www.gnu.org/licenses/>.

#include "individualsettings.h"
#include "ui_individualsettings.h"
#include "mainwindow.h"
#include "pingresult.h"

#include <QSettings>
#include <QtDebug>

// Form values get set in slot_setTask()
IndividualSettings::IndividualSettings(QWidget *parent) : QDialog(parent),
	ui(new Ui::IndividualSettings)
	{
	ui->setupUi(this);
	restoreSettings();
	viewType = new QButtonGroup();
	viewType->addButton(ui->radioButton_useRDP);
	viewType->addButton(ui->radioButton_useVNC);

	vncCredType = new QButtonGroup();
	vncCredType->addButton(ui->radioButton_VNCdefaultCreds);
	vncCredType->addButton(ui->radioButton_VNCpw);
	vncCredType->addButton(ui->radioButton_VNCmsLogin);
	vncCredType->addButton(ui->radioButton_customVNCpassword);

	warningType = new QButtonGroup();
	warningType->addButton(ui->radioButton_warningDefault);
	warningType->addButton(ui->radioButton_warningYes);
	warningType->addButton(ui->radioButton_warningNo);

	ui->lineEdit_customVNCpassword->setEchoMode(mwptr->getHidePasswords() ? QLineEdit::Password : QLineEdit::PasswordEchoOnEdit);
	ui->lineEdit_customWindowsPW->setEchoMode(mwptr->getHidePasswords() ? QLineEdit::Password : QLineEdit::PasswordEchoOnEdit);

	connect(ui->pushButton_close, SIGNAL(clicked(bool)), this, SLOT(slot_closeClicked()));
	connect(ui->pushButton_save, SIGNAL(clicked(bool)), this, SLOT(slot_saveClicked()));
	connect(ui->pushButton_defaultSettings, SIGNAL(clicked(bool)), this, SLOT(slot_clearSettingsClicked()));

	ui->comboBox_os->addItem("Default");
	ui->comboBox_os->addItems(mwptr->osList);
	ui->comboBox_os->setCurrentIndex(0);

//	this->setStyleSheet("QWidget#IndividualSettings { background-color:"
//								" qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,"
//								" stop: 0 #CCE5FF, stop: 1 #EEFFFF);}"
//							  " QGroupBox {background-color:"
//							  " qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,"
//							  " stop: 0 #CCE5FF, stop: 1 #EEFFFF);}");

	this->setStyleSheet(
		"QGroupBox"
			"{"
			"background-color:"
			"qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,"
			"stop: 0 #CCE5FF, stop: 1 #EEFFFF);"
			"margin: 5px; padding: 12px;"
			"}"
		"QGroupBox::title"
			"{"
			"margin: 0 5 0 5 px;"
			"subcontrol-origin: margin;"
			"subcontrol-position: top left;"
			"position: relative;"
			"left: 8px;"
			"}"
		"QWidget#IndividualSettings"
			"{"
			"background-color:"
			"qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,"
			"stop: 0 #CCE5FF, stop: 1 #EEFFFF);"
			"}"
		);

	this->show();
	mwptr->forceOnscreen(this);
	this->setWindowTitle("MultiVNC - custom settings for " + static_cast<PingResult *>(parent)->getHost());
	}

IndividualSettings::~IndividualSettings()
	{
	delete viewType;
	delete vncCredType;
	delete warningType;
	delete ui;
	}

// ------------------------- private functions -------------------------

void IndividualSettings::restoreSettings()
	{
	QSettings mvc("WSS-DDC", "MultiVNC-Qt\\Settings");
	if(mvc.contains("ConfigIndividualPos"))
		{
		QPoint pos = mvc.value("ConfigIndividualPos").toPoint();
		move(pos);
		}
	if(mvc.contains("ConfigIndividualSize"))
		{
		QSize size = mvc.value("ConfigIndividualSize").toSize();
		resize(size);
		}
	}

// --------------------------- private slots ---------------------------

void IndividualSettings::slot_closeClicked()
	{
	updatePwOption();
	QSettings mvc("WSS-DDC", "MultiVNC-Qt\\Settings");
	mvc.setValue("ConfigIndividualPos", pos());
	mvc.setValue("ConfigIndividualSize", size());
	close();
	}
