// This file is part of MultiVnc-Qt.  MultiVnc-Qt is copyright 2012-2022
// by Robert W. Babcock and WSS Division of DDC and is distributed under
// the terms of the GNU General Public License.  Contact the author at
// wssddc@wssddc.com or see the project web page at
// <https://www.wssddc.com/multivnc/>.
//
// MultiVnc-Qt uses the open source Qt toolkit from the Qt Project
// (qt-project.org) and The Qt Company (www.qt.io).
//
// MultiVnc-Qt is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// MultiVnc-Qt is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with MultiVnc-Qt.  If not, see <https://www.gnu.org/licenses/>.

#ifndef PINGRESULT_H
#define PINGRESULT_H

#include "mainwindow.h"
#include "individualsettings.h"

#include <QDateTime>
#include <QLinkedList>
#include <QQueue>
#include <QSignalMapper>
#include <QWidget>

#define PING_BUF_SIZE	100
#define NO_PING	99999
#define INVALID_PING	99998

namespace Ui {
	class PingResult;
	}

class PingResult : public QWidget
	{
	Q_OBJECT

public:
	Ui::PingResult *ui;
	explicit PingResult(QWidget *parent = nullptr, int task = 0);
	~PingResult() override;
	void clearWOLsent();
	void processData(bool sound);
	void resetData();
	void setButtonColor(enum buttonsColors);
	void setCustomVNCpassword(QString pw);
	void setHost(QString host);
	void setIPtext(QString iptext);
	void setLastUpTime(QDateTime dt);
	void setVNCpwType(VNCpasswordType pwt);
	void setRDPsize(QPoint xy);
	void setRDPstatus (bool newstatus);
	void setCustomOS(int newos);
	void setSlowness(bool slow);
	void setWelcomeStatus(bool newstatus);
	void setWelcomeUserNumber(int user);

	bool getRDPstatus();
	int getCustomOS();
	bool getWelcomeStatus();
	int getWelcomeUserNumber();
	bool getWelcomePWstatus();
	bool getSlowness();
	QString getCustomWindowsPW();
	QString getCustomWindowsName();
	void setCustomWindowsName(QString username);
	void setCustomWindowsPW(QString newpw);

	void setTaskNum(int newnum);
	void setWOLhappened();
	void setWOLsent();
	void updateButtonLabels();
	void vncClicked(bool tiny);
	bool wakeSent();
	QDateTime getLastUpTime();
	QPoint getRDPsize();
	QString getCustomVNCpassword();
	QString getHost();
	QString getIPtext();
	void logcheck(bool multi);
	void upcheck(bool multi);

	warnSetting getWarnSetting();
	void setWarnSetting(warnSetting warn);
	QString pickUsername();
	QString pickPW();
	VNCpasswordType getVNCpwType();
	targetState isUp();
	bool nameIsIP;

private:
	bool needVNCpw();
	bool needCustomVNCpassword();
	bool needMSpw();
	void plotData(bool sound);
	void rdpClicked(bool windowed);
	void contextMenuEvent(QContextMenuEvent *event) override;
	HWND findWindow(QString title, bool nameIsIP);
	void sendQstring(QString str);
	void sendKey(short vk, bool bExtended, short shiftState);
	void sendCAD(int sleepAfter);
	void sendCredsFromContextMenu(bool pwOnly);
	bool WOLsent;
	bool deletionInProgress;
	bool useRDP;
	int customOS;
	bool slowPC;
	bool useWelcome;
	int welcomeUserNumber;
	int mytask;
	QSignalMapper *signalMapperHost;
	QDateTime lastUpTime;
	QLinkedList<unsigned long> pingData;
	QPoint winsizeRDP;
	QQueue<unsigned long> pingQueue;
	QString customVNCpassword;
	QString customWindowsName;
	QString customWindowsPW;
	VNCpasswordType VNCpwType;
	QAction *raiseActContext;
	QAction *sendCredsContext;
	QAction *sendPwContext;
	QAction *loginActContext;
	QAction *logoffActContext;
	QAction *shutdownActContext;
	QAction *lockActContext;
	QAction *unlockActContext;
	QAction *closeWindowActContext;
	QAction *queryLoggedOnActContext;
	QAction *queryUpTimeActContext;
	IndividualSettings *iset;
	bool isetOpen;
	warnSetting localWarn;

public slots:
	void slot_newData(unsigned long pingTime);
	void slot_VNClargeClicked();
	void slot_VNCsmallClicked();
	void slot_settingsClicked();
	void slot_closeFromContextMenu();
	void slot_sendCredsFromContextMenu();
	void slot_sendPwFromContextMenu();
	void slot_loginFromContextMenu();
	void slot_logoffFromContextMenu();
	void slot_shutdownFromContextMenu();
	void slot_lockFromContextMenu();
	void slot_unlockFromContextMenu();

private slots:
	void slot_closeSettings();
	void slot_WOLclicked();
	void slot_delClicked();
	void slot_raiseFromContextMenu();
	void slot_LoggedOnUserFromContextMenu();
	void slot_upTimeFromContextMenu();

signals:
	void delHostSignal(int task);
	void newHostSignal(int task);
	void signalWOLsent(int task);
	};

#endif // PINGRESULT_H
