// This file is part of MultiVnc-Qt.  MultiVnc-Qt is copyright 2012-2022
// by Robert W. Babcock and WSS Division of DDC and is distributed under
// the terms of the GNU General Public License.  Contact the author at
// wssddc@wssddc.com or see the project web page at
// <https://www.wssddc.com/multivnc/>.
//
// MultiVnc-Qt uses the open source Qt toolkit from the Qt Project
// (qt-project.org) and The Qt Company (www.qt.io).
//
// MultiVnc-Qt is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// MultiVnc-Qt is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with MultiVnc-Qt.  If not, see <https://www.gnu.org/licenses/>.

#ifndef PINGTASK_H
#define PINGTASK_H

#include <specstrings.h>
#include <WinSock2.h>
#include <iphlpapi.h>
#define PIO_APC_ROUTINE_DEFINED
#include <winternl.h>
#ifdef __GNUC__
	#include <icmpapi.h>
#else
	#include "wininclude\icmpapi.h"
#endif

#include "mainwindow.h"

class PingResult;

class PingTask : public QObject
	{
	Q_OBJECT
public:
	explicit PingTask(QObject *parent = nullptr, int taskno = 0);
	~PingTask() override;
	void startPing();
	void setIP(unsigned long ip);
	void setIPvalidity(bool valid);
	void setPingCompleted();
	void setPingTiming(int interval, int wait);
	void setTaskNum(int newnum);
	void cleanupPingDone();
	bool getIPvalidity();
	bool isPingInProgress();
	unsigned long getIP();
	HANDLE hIcmpFile;
	LPVOID ReplyBuffer;
	QTimer *timer;

private:
	int mytask;
	bool pingInProgress;
	bool validIP;
	char SendData[12];
	int SendSize;
	int pingInterval;
	int pingWait;
	unsigned long ipaddr;
	DWORD ReplySize;
	DWORD dwRetVal;
	PVOID ReplyApcContext;
	PingResult *pingform;
	QString host;

signals:
	void signal_pingTime(int taskno, unsigned long ptime);

private slots:
	void slot_pingtest();

public slots:
	};

#endif // PINGTASK_H
