// This file is part of MultiVnc-Qt.  MultiVnc-Qt is copyright 2012-2022
// by Robert W. Babcock and WSS Division of DDC and is distributed under
// the terms of the GNU General Public License.  Contact the author at
// wssddc@wssddc.com or see the project web page at
// <https://www.wssddc.com/multivnc/>.
//
// MultiVnc-Qt uses the open source Qt toolkit from the Qt Project
// (qt-project.org) and The Qt Company (www.qt.io).
//
// MultiVnc-Qt is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// MultiVnc-Qt is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with MultiVnc-Qt.  If not, see <https://www.gnu.org/licenses/>.

#include "valueslider.h"
#include <QStyleOptionSlider>
#include <QToolTip>

// This is derived from a posting at
// https://stackoverflow.com/questions/18383885/qslider-show-min-max-and-current-value

// Show slider value as a tooltip when value changes.
// Tooltip positioning assumes a vertical slider.
// Tracking should be on or else the value displayed will only be updated when the mouse is released.

valueSlider::valueSlider(QWidget * parent) : QSlider(parent) {}

valueSlider::valueSlider(Qt::Orientation orientation, QWidget * parent) : QSlider(orientation, parent) {}

void valueSlider::sliderChange(QAbstractSlider::SliderChange change)
	{
	QSlider::sliderChange(change);

	if(change == QAbstractSlider::SliderValueChange)
		{
		QStyleOptionSlider opt;
		initStyleOption(&opt);

		QRect sr = style()->subControlRect(QStyle::CC_Slider, &opt, QStyle::SC_SliderHandle, this);
		QPoint bottomRightCorner = sr.topLeft();

		QToolTip::showText(mapToGlobal( QPoint( bottomRightCorner.x()-40, bottomRightCorner.y()-20 ) ), QString::number(value()), this);
		}
	}
